# -*- coding: utf-8 -*-
import os

import pkg_resources

from omc.common import CmdTaskMixin
from omc.config import settings
from omc.core import Resource
from omc.core.decorator import filecache


class Arthas(Resource, CmdTaskMixin):
    def _description(self):
        return 'Arthas - JVM Debug Tools'

    @filecache(duration=-1, file=os.path.join(settings.OMC_COMPLETION_CACHE_DIR, 'completion'))
    def _get_resource_completion(self):
        return ""

    def _run(self):
        arthas = pkg_resources.resource_filename('omc_arthas.lib', 'arthas-boot.jar')
        cmd = "java -jar %s" % arthas
        self.run_cmd(cmd)



from setuptools import setup, find_packages
install_requires = [
    'omc>=0.2.1'
]


setup(
    name='omc-arthas',
    version="0.0.2",
    description='arthas plugin for omc',
    license='MIT',
    author='Lu Ganlin',
    author_email='linewx1981@gmail.com',
    url='https://github.com/linewx/omc-arthas',
    packages=find_packages(),
    package_data={'omc_arthas.lib': ['**', '**/*', '**/**/*']},
    install_requires=install_requires,
)
